@@ -6,7 +6,7 @@ my $jumble = Games::Jumble->new;
 $jumble->num_words(6);
 $jumble->dict('/home/doug/crossword_dict/unixdict.txt');
 
-my @jumble = $jumble->create_puzzle;
+my @jumble = $jumble->create_jumble;
 
 foreach my $word (@jumble) {
     print "$word\n";
